<?php
/*
Plugin Name: Hyperlink Rotator
Plugin URI: https://wpscriptly.com/
Description: Rotates hyperlinks with images after the second paragraph in a post.
Version: 1.9
Author: SB
Author URI: https://wpscriptly.com/
License: GPL2
*/
function hr_enqueue_styles() {
    $css_file_path = plugin_dir_path(__FILE__) . 'style.css';
    $css_version = filemtime($css_file_path);
    wp_enqueue_style('hr-rotator-style', plugin_dir_url(__FILE__) . 'style.css', array(), $css_version);
}
add_action('wp_enqueue_scripts', 'hr_enqueue_styles');

function hr_add_admin_menu() {
    add_options_page(
        'Hyperlink Rotator', 
        'Hyperlink Rotator', 
        'manage_options', 
        'hyperlink-rotator', 
        'hr_options_page'
    );
}
add_action('admin_menu', 'hr_add_admin_menu');

function hr_settings_init() {
    register_setting('hr_options', 'hr_links', [
        'sanitize_callback' => 'hr_sanitize_links',
    ]);
    register_setting('hr_options', 'hr_paragraph_number', [
        'sanitize_callback' => 'absint',
    ]);

    add_settings_section(
        'hr_section', 
        __('Manage your hyperlinks', 'wordpress'), 
        null, 
        'hyperlink-rotator'
    );

    add_settings_field(
        'hr_links', 
        __('Links', 'wordpress'), 
        'hr_links_render', 
        'hyperlink-rotator', 
        'hr_section'
    );

    add_settings_field(
        'hr_paragraph_number', 
        __('Paragraph Number', 'wordpress'), 
        'hr_paragraph_number_render', 
        'hyperlink-rotator', 
        'hr_section'
    );
}
add_action('admin_init', 'hr_settings_init');

function hr_sanitize_links($input) {
    $links = explode("\n", $input);
    $sanitized_links = [];

    foreach ($links as $link) {
        $parts = explode('|', trim($link));
        if (count($parts) === 3) {
            $url = esc_url_raw($parts[0]);
            $name = sanitize_text_field($parts[1]);
            $image_url = esc_url_raw($parts[2]);

            if (!empty($url) && !empty($name) && !empty($image_url)) {
                $sanitized_links[] = "$url|$name|$image_url";
            }
        }
    }

    return $sanitized_links;
}

function hr_links_render() {
    $links = get_option('hr_links', []);
    if (!is_array($links)) {
        $links = [];
    }
    ?>
    <textarea name="hr_links" rows="10" cols="50" class="large-text"><?php echo esc_textarea(implode("\n", $links)); ?></textarea>
    <p class="description">Enter each link in the format: URL|Name|ImageURL, one per line.</p>
    <?php
}

function hr_paragraph_number_render() {
    $paragraph_number = get_option('hr_paragraph_number', 2);
    ?>
    <input type="number" name="hr_paragraph_number" value="<?php echo esc_attr($paragraph_number); ?>" class="small-text" min="1" />
    <p class="description">Enter the paragraph number after which the link should be inserted. Default is 2.</p>
    <?php
}

function hr_options_page() {
    ?>
    <form action="options.php" method="post">
        <h2>Hyperlink Rotator</h2>
        <?php
        settings_fields('hr_options');
        do_settings_sections('hyperlink-rotator');
        submit_button();
        ?>
    </form>
    <?php
}

function hr_get_links_from_db() {
    $links = get_option('hr_links', []);
    if (!is_array($links)) {
        return [];
    }

    return array_map(function($line) {
        list($url, $name, $image_url) = explode('|', $line, 3);
        return '<a href="' . esc_url(trim($url)) . '" class="rotated-link" target="_blank"><img src="' . esc_url(trim($image_url)) . '" alt="' . esc_attr(trim($name)) . '" /></a>';
    }, $links);
}

function hr_rotate_hyperlinks($content) {
    if (is_single() && in_the_loop() && is_main_query()) {
        $links = hr_get_links_from_db();
        $paragraph_number = get_option('hr_paragraph_number', 2);

        if (empty($links)) {
            return $content;
        }

        $selected_link = $links[array_rand($links)];
        $selected_link_wrapped = '<div class="rotated-link-container">' . $selected_link . '</div>';
        $paragraphs = explode('</p>', $content);

        if (count($paragraphs) >= $paragraph_number) {
            $paragraphs[$paragraph_number - 1] .= '</p>' . $selected_link_wrapped . '<p>';
            $content = implode('</p>', $paragraphs);
        }
    }
    return $content;
}
add_filter('the_content', 'hr_rotate_hyperlinks');